##  Answering Survey Questions
In the Survey tab of a fact sheet, you can view and respond to survey questions related to that fact sheet. Surveys are an effective method for collecting data from relevant stakeholders. Fact sheet subscribers receive email notifications when a survey includes questions about the fact sheets they’re subscribed to. To learn more, see the detailed guide [Surveys](https://help.sap.com/docs/leanix/ea/surveys?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX surveys streamline data collection and collaboration with seamless integration with fact sheets.").
Clicking Edit next to a survey question opens the survey response form, where you can provide your answers. The responses are automatically updated in the corresponding fields of the fact sheet. To learn more, see [Responding to Surveys](https://help.sap.com/docs/leanix/ea/responding-to-surveys?locale=en-US&state=PRODUCTION&version=CLOUD "Responding to surveys is crucial for providing feedback on enterprise architecture. Access surveys via the collaboration tab, fact sheets, or dashboard. Learn how to fill them and provide your insights.").
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio7dae8663d83344ca877631b1b1e16313_LowRes.png)
Reviewing and Answering Survey Questions
